#!/usr/bin/bash 
# To be used by client with the command:
#   sh -x <(curl https://ftp.eso.org/pub/elt/repos/fedora/eso/GetDevEnv.sh) 
# or
#   sh -x <(curl https://ftp.eso.org/pub/elt/repos/fedora/eso/GetDevEnv.sh) <release>
# being release any of the subdirectories in
#   https://ftp.eso.org/pub/elt/repos/fedora/eso/$releasever 

# Default release elt-latest
set -e

if rpm -q puppet-elt >/dev/null 2>&1 ; then
 echo "RPM puppet-elt already installed"
 exit 0
fi

# ELTDEV-1156
MINSIZE=20
size_root=`/usr/bin/df -H / | tail -1 | gawk '{print $2}' | sed 's/G//'`
#echo size_root=$size_root
if [ $size_root -le $MINSIZE ]; then
  echo ""
  echo "WARNING: The root partition might not big enough (>${MINSIZE}G):"
  df -H /
  freesize=`vgs | tail -1 | gawk '{print $7}'`
  #echo freesize=$freesize
  if [ "$freesize" !=  "0" ]; then
    vgs
    echo ""
    echo "Some free disk space still available for the root partition"
    echo "You may extend it, as root, with the command:"
    echo "  lvextend /dev/mapper/fedora_fedora-root -l100%FREE"
    echo "  xfs_growfs /dev/mapper/fedora_fedora-root"
  fi
  echo ""
  echo -n "Do you want to continue [yn] (n)? : "
  read answ
  if [ -z "$answ" -o "$answ" != "y" ]; then
    exit 0
  fi
fi

release=elt
release_dir=elt-latest
while [ -n "$1" ]; do
  case $1 in
    --install|-i) install="yes"
      shift ;;
    --role|-r) export ELT_ROLE=$2
      shift; shift ;;
    *) release=`echo $1 | sed 's/-beta//'`
       release_dir=`echo $1 | sed 's/puppet-//'`
      shift ;;
  esac
done

# releasever=34,35,36... for fedora-34,fedora-35,fedora-36 and so on
releasever="$(rpm --query --file --queryformat '%{VERSION}\n' /etc/system-release)";

# Check the release repository exists:
if `curl https://ftp.eso.org/pub/elt/repos/fedora/eso/$releasever/$release_dir 2>/dev/null | grep -q "was not found"` 
then
  echo "ERROR. Cannot find repository  https://ftp.eso.org/pub/elt/repos/fedora/eso/$releasever/$release_dir"
  exit 1
fi

# ELTDEV-1156: we use repositories with prefix "eeso-" to avoid conflicting with potential existing repofiles with prefix "eso-".
dnf clean all
dnf -y --nogpgcheck --disablerepo="*" \
--repofrompath eeso-elt,https://ftp.eso.org/pub/elt/repos/fedora/eso/$releasever/elt/x86_64 \
--repofrompath eeso-elt-release,https://ftp.eso.org/pub/elt/repos/fedora/eso/$releasever/$release_dir/x86_64 \
--repofrompath eeso-fedora,https://ftp.eso.org/pub/elt/repos/fedora/releases/$releasever/Everything/x86_64/os \
--repofrompath eeso-fedora-modular,https://ftp.eso.org/pub/elt/repos/fedora/releases/$releasever/Modular/x86_64/os \
--repofrompath eeso-fedora-updates,https://ftp.eso.org/pub/elt/repos/fedora/updates/$releasever/Everything/x86_64 \
--repofrompath eeso-fedora-updates-modular,https://ftp.eso.org/pub/elt/repos/fedora/updates/$releasever/Modular/x86_64 \
install puppet-$release

if [ $? -ne 0 ]; then
  echo "Download of RPM puppet-elt failed"
  echo "Please check file https://ftp.eso.org/pub/elt/repos/fedora/eso/$releasever/$release/x86_64/Packages/puppet-elt\* exist" 
  exit 1
fi

if [ "$install" = "yes" ]; then
  cd /root/elt
  echo "Executing:  puppet-force-align"
  ./puppet-force-align
#  reboot &
fi


exit $?
