#!/usr/bin/bash

Help()
{
   # Display Help
   echo "Print SW, HW and application info."
   echo
   echo "Syntax: $0 [-h]"
   echo "options:"
   echo "-h     Print this help"
   echo
}

# Get the options
while getopts "hv" option; do
   case $option in
      h) # display Help
         Help
         exit;;
      *) # Invalid option
         echo "Error: Invalid option"
         exit;;
   esac
done

# Colors
white="\e[39m"
red="\e[1;31m"
eso_logo_colors="\e[37m\e[44m"
christmas_logo_colors="\e[1;37m\e[41m"

eso_logo[0]=" $eso_logo_colors     ✦     \e[0m"
eso_logo[1]=" $eso_logo_colors  ╔═╕ ╔═╕  \e[0m"
eso_logo[2]=" $eso_logo_colors  ╠╡  ╚═╗ ✦\e[0m"
eso_logo[3]=" $eso_logo_colors✦ ╚═╛ ╘═╝  \e[0m"
eso_logo[4]=" $eso_logo_colors    ╔═╗    \e[0m"
eso_logo[5]=" $eso_logo_colors    ║ ║    \e[0m"
eso_logo[6]=" $eso_logo_colors    ╚═╝    \e[0m"
eso_logo[7]=" $eso_logo_colors     ✦     \e[0m"

christmas_logo[0]=" $christmas_logo_colors     ✱     \e[0m"
christmas_logo[1]=" $christmas_logo_colors    /.\    \e[0m"
christmas_logo[2]=" $christmas_logo_colors   /o..\   \e[0m"
christmas_logo[3]=" $christmas_logo_colors   /..o\   \e[0m"
christmas_logo[4]=" $christmas_logo_colors  /.o..o\  \e[0m"
christmas_logo[5]=" $christmas_logo_colors  /...o.\  \e[0m"
christmas_logo[6]=" $christmas_logo_colors /..o....\ \e[0m"
christmas_logo[7]=" $christmas_logo_colors ^^^[_]^^^ \e[0m"

DATE=`date +%-m%d`

if ((DATE >= 1224 && DATE <= 1226)); then
   main_color="\e[31m"
   logo=("${christmas_logo[@]}");
else
   main_color="\e[0;34m"
   logo=("${eso_logo[@]}");
fi

# Get free memory
IFS=" " read USED AVAIL TOTAL <<<$(free -htm | grep "Mem" | awk {'print $3,$7,$2'})

# Get processors
PROCESSOR_NAME=`grep "model name" /proc/cpuinfo  | head -1 | cut -d ' ' -f3-`

# Get cores
CORES=`lscpu | grep "^CPU(s):" | awk '{print $2}'`

# Detect the type of virtualization
HARDWARE="unknown"

if [[ -f /usr/sbin/virt-what && -f /usr/sbin/dmidecode && $EUID -eq 0 ]]
then
   HARDWARE=`virt-what | xargs`
   if [[ "$HARDWARE" == "" ]]
      then
      HARDWARE="bare-metal - "`dmidecode | grep ModelName | awk -F= '{print $3}'`
   fi
fi

# Check for newer DevEnv
COMMAND=`yum list puppet-elt 2>/dev/null  | grep Available`
if [[ "$COMMAND" =~ Available ]]
then
   NEW_V=`yum list puppet-elt  2>/dev/null | tail -1 | awk '{printf($2)}'`
   NEW_V="(Latest $NEW_V)"
else
   NEW_V=""
fi

# Determine CII, MAL and RAD version
COMMAND=`rpm -q --queryformat='%{version}|' elt-ciisrv-common elt-mal elt-rad | tr "\n" "|" | sed -e "s/package [a-z-]* is not installed/none/g"`
IFS="|" read CII MAL RAD <<< "$COMMAND"

# Detect synchronization
SYNC="unknown"
if [[ -f /elt/trs/bin/trsSyncStatus ]]
then
   COMMAND=`/elt/trs/bin/trsSyncStatus | grep status | wc -l`
   if [[ $COMMAND -eq 4 ]]
   then
      SYNC="PTP and NTP"
   else
      COMMAND=`/elt/trs/bin/trsSyncStatus | grep status | tail -1 | cut -d' ' -f1`
       case $COMMAND in
         PTP)
            SYNC="PTP"
            ;;
         NTP)
            SYNC="NTP"
            ;;
         Service)
            SYNC="none"
            ;;
       esac
    fi
fi

# Determine uptime
UPTIME=`uptime -p | awk -F "," "NF-=1" OFS=','`
if [[ "$UPTIME" == "" ]]
then
   UPTIME="up 0 hours"
fi

echo -e "
${logo[0]}           $main_color CPU : $white$PROCESSOR_NAME
${logo[1]}     $main_color CPU Cores : $white$CORES
${logo[2]}    $main_color Hypervisor : $white$HARDWARE
${logo[3]}        $main_color Memory : $white$USED used, $AVAIL avail, $TOTAL total
${logo[4]}        $main_color DevEnv : $white`rpm -q --queryformat='%{version}' puppet-elt` $red$NEW_V
${logo[5]}        $main_color Kernel : $white`uname -r`
${logo[6]}    $main_color Clock Sync : $white$SYNC
${logo[7]}        $main_color Uptime : $white$UPTIME
                   $main_color CII MAL : $white$MAL
                   $main_color CII SRV : $white$CII
                       $main_color RAD : $white$RAD
"
